@@ -36,45 +36,45 @@
 <context>
     <name>DirectoriesPage</name>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="20"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="23"/>
         <source>Filter directories</source>
         <translation>Verzeichnisse filtern</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="81"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="84"/>
         <source>Show errors</source>
         <translation>Zeige Fehler</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="92"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="161"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="95"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="164"/>
         <source>Rescan</source>
         <translation>Scannen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="103"/>
         <source>Resume</source>
         <translation>Fortsetzen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="168"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="103"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="171"/>
         <source>Pause</source>
         <translation>Pausieren</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="110"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="175"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="113"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="178"/>
         <source>Open in file browser</source>
         <translation>Im Dateibrowser öffnen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="147"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="150"/>
         <source>Copy label/ID</source>
         <translation>Namen/ID kopieren</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="152"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="155"/>
         <source>Copy path</source>
         <translation>Pfad kopieren</translation>
     </message>
@@ -141,48 +141,48 @@
         <translation type="vanished">Syncthing öffnen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="241"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="246"/>
         <source>Global</source>
         <translation>Globale</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="248"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="253"/>
         <source>Global incoming traffic</source>
         <translation>Globaler eingehender Datenverkehr</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="266"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="271"/>
         <source>Local</source>
         <translation>Lokale</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="273"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="278"/>
         <source>Global outgoing traffic</source>
         <translation>Globaler ausgehender Datenverkehr</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="29"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="33"/>
         <source>Directories</source>
         <translation>Verzeichnisse</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="35"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="39"/>
         <source>Devices</source>
         <translation>Geräte</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="41"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="45"/>
         <source>Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="47"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="51"/>
         <source>History</source>
         <translatorcomment>&quot;Letzte Änderungen&quot; is too long</translatorcomment>
         <translation>Änderungen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="99"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="104"/>
         <source>Toggle filter</source>
         <translation>Filter ein-/ausblenden</translation>
     </message>
@@ -224,6 +224,16 @@
         <translatorcomment>Plural: https://www.duden.de/rechtschreibung/Status</translatorcomment>
         <translation>Status für passiven Modus</translation>
     </message>
+    <message>
+        <location filename="../lib/appearanceoptionpage.ui" line="140"/>
+        <source>Optional GUI elements</source>
+        <translation>Optionale Elemente</translation>
+    </message>
+    <message>
+        <location filename="../lib/appearanceoptionpage.ui" line="147"/>
+        <source>Show tab texts</source>
+        <translation>Text-Beschriftung der Tab-Buttons</translation>
+    </message>
     <message>
         <source>Colors</source>
         <translation type="vanished">Farben</translation>
@@ -244,17 +254,17 @@
 <context>
     <name>Plasmoid::SettingsDialog</name>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="124"/>
+        <location filename="../lib/settingsdialog.cpp" line="126"/>
         <source>Plasmoid</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="132"/>
+        <location filename="../lib/settingsdialog.cpp" line="134"/>
         <source>Web view</source>
         <translation>Weboberfläche</translation>
     </message>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="138"/>
+        <location filename="../lib/settingsdialog.cpp" line="140"/>
         <source>Extras</source>
         <translation></translation>
     </message>
@@ -275,17 +285,17 @@
 <context>
     <name>Plasmoid::SyncthingApplet</name>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="379"/>
+        <location filename="../lib/syncthingapplet.cpp" line="380"/>
         <source>About</source>
         <translation>Über Syncthing Plasmoid</translation>
     </message>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="391"/>
+        <location filename="../lib/syncthingapplet.cpp" line="392"/>
         <source>New notifications</source>
         <translation>Neue Benachrichtigungen</translation>
     </message>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="548"/>
+        <location filename="../lib/syncthingapplet.cpp" line="550"/>
         <source>D-Bus error - unable to </source>
         <translation>D-Bus-Fehler bei Aktion </translation>
     </message>
