@@ -1450,6 +1450,8 @@ SettingsDialog::SettingsDialog(Data::SyncthingConnection *connection, QWidget *p
 #endif
     });
     category->setIcon(QIcon::fromTheme(QStringLiteral("system-run"), QIcon(QStringLiteral(":/icons/hicolor/scalable/apps/system-run.svg"))));
+    m_launcherSettingsCategory = static_cast<int>(categories.size());
+    m_launcherSettingsPageIndex = 1;
     categories << category;
 
     categories << values().qt.category();
@@ -1478,25 +1480,25 @@ void SettingsDialog::init()
         QIcon::fromTheme(QStringLiteral("tools-wizard"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/tools-wizard.svg"))));
     startWizardButton->setFlat(true);
     startWizardButton->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-    connect(startWizardButton, &QPushButton::clicked, this, &SettingsDialog::showWizard);
+    connect(startWizardButton, &QPushButton::clicked, this, &SettingsDialog::wizardRequested);
     addHeadingWidget(startWizardButton);
 
     // some settings could be applied without restarting the application, good idea?
     //connect(this, &Dialogs::SettingsDialog::applied, bind(&Dialogs::QtSettings::apply, &Settings::qtSettings()));
 }
 
-void SettingsDialog::showWizard()
-{
-    auto *const wizard = Wizard::instance();
-    QtUtilities::centerWidget(wizard);
-    wizard->show();
-}
-
 void SettingsDialog::hideConnectionStatus()
 {
     m_connectionsOptionPage->hideConnectionStatus();
 }
 
+void SettingsDialog::selectLauncherSettings()
+{
+    if (m_launcherSettingsCategory >= 0 && m_launcherSettingsPageIndex >= 0) {
+        selectPage(m_launcherSettingsCategory, m_launcherSettingsPageIndex);
+    }
+}
+
 } // namespace QtGui
 
 INSTANTIATE_UI_FILE_BASED_OPTION_PAGE_NS(QtGui, ConnectionOptionPage)
